@@ -7,7 +7,7 @@
 createExtract <- function(result,
                           what) {
   extract <- structure(result,
-                       class = c("extract", "list"),
+                       class = c("extractSTA", "list"),
                        what = what)
   return(extract)
 }
@@ -25,18 +25,21 @@ createExtract <- function(result,
 #'
 #' @export
 as.data.frame.extract <- function(x,
-                                  row.names = NULL,
-                                  optional = FALSE,
-                                  ...) {
+                                     row.names = NULL,
+                                     optional = FALSE,
+                                     ...) {
+  .Deprecated("extractSTA",
+              msg = c("'as.data.frame' for extract is deprecated.\n",
+                      "Use 'extractSTA' with 'asDataFrame = TRUE' instead"))
   if ("heritability" %in% attr(x, which = "what")) {
-      herit <- sapply(X = x, FUN = `[`, "heritability")
-      traits <- unique(unlist(sapply(X = herit, names)))
-      heritDF <- data.frame(trial = names(x), row.names = row.names,
-                            stringsAsFactors = FALSE)
-      for (trait in traits) {
-        heritDF[[trait]] <- sapply(herit, `[`, trait)
-      }
-      return(heritDF)
+    herit <- sapply(X = x, FUN = `[`, "heritability")
+    traits <- unique(unlist(sapply(X = herit, names)))
+    heritDF <- data.frame(trial = names(x), row.names = row.names,
+                          stringsAsFactors = FALSE)
+    for (trait in traits) {
+      heritDF[[trait]] <- sapply(herit, `[`, trait)
+    }
+    return(heritDF)
   } else {
     stop("Conversion to data.frame only possible if heritabilities present.\n")
   }
